import { TypedEmitter } from 'tiny-typed-emitter';
import { ProductSchema } from '@byondrnd/showroom-schemas';
import { Visualizer } from '../Visualizer';
declare type OnSceneLoaded = (eventData: {
    zone: number;
}) => void;
declare type OnVisualizerLoaded = (eventData: {
    visualizer: Visualizer;
}) => void;
declare type OnProductChange = (eventData: {
    product: ProductSchema.IProduct;
}) => void;
declare type onHotspotClicked = (eventData: {
    application: string;
}) => void;
declare type onProductAddedToFavorite = (eventData: {
    favorites: IFavoriteProductList;
}) => void;
declare type onSetAddedToFavorite = (eventData: {
    favoritesSet: IFavoriteSetList;
}) => void;
declare type onProductAddedToCart = (eventData: {
    cart: string[];
}) => void;
declare type onProductRemovedFromFavorite = (eventData: {
    favorites: IFavoriteProductList;
}) => void;
declare type onSetRemovedFromFavorite = (eventData: {
    favoritesSet: IFavoriteSetList;
}) => void;
declare type onProductRemovedFromCart = (eventData: {
    cart: string[];
}) => void;
interface IEventSystem {
    sceneLoaded: OnSceneLoaded;
    visualizerLoaded: OnVisualizerLoaded;
    productChanged: OnProductChange;
    hotspotClicked: onHotspotClicked;
    productAddedToFavorite: onProductAddedToFavorite;
    setAddedToFavorite: onSetAddedToFavorite;
    productAddedToCart: onProductAddedToCart;
    productRemovedFromFavorite: onProductRemovedFromFavorite;
    setRemovedFromFavorite: onSetRemovedFromFavorite;
    productRemovedFromCart: onProductRemovedFromCart;
}
export declare type EventSystemEventSignature = keyof IEventSystem;
export declare type EventSystemEventDataSignature = Parameters<IEventSystem[EventSystemEventSignature]>;
export declare type IFavorite = {
    productSku: string;
    application: string;
};
export declare type IFavoriteSet = {
    id: string;
    sceneId: string;
    zoneIndex: string;
    image: string;
    favorites: Array<IFavorite>;
};
export declare type IFavoriteProductList = Array<IFavorite>;
export declare type IFavoriteSetList = Array<IFavoriteSet>;
export declare type IFilter = {
    name: string;
    options: string[];
};
export declare type IProduct = {
    sku: string;
    title: string;
    description: string;
    image: string;
    application: string;
    filters: IFilter[];
    price: string;
};
export declare abstract class EventSystem extends TypedEmitter<IEventSystem> {
    abstract initAndLoad(): any;
    abstract GetProductList(application: string, filters?: Array<IFilter>): Array<IProduct>;
    abstract GetApplicationsList(): Array<{
        application: string;
        image: string;
    }>;
    abstract GetFilters(application: string): Array<IFilter>;
    abstract displayProduct(productSku: string, application: string): Promise<void>;
    abstract addProductToFavorite(productSku: string, application: string): IFavoriteProductList;
    abstract removeProductFromFavorite(productSku: string, application: string): IFavoriteProductList;
    abstract getProductFavoriteList(): IFavoriteProductList;
    abstract addSetToFavorite(): Promise<IFavoriteSetList>;
    abstract removeSetFromFavorite(set: IFavoriteSet): IFavoriteSetList;
    abstract getSetFavoriteList(): IFavoriteSetList;
    abstract addProductToCart(productSku: string): Array<string>;
    abstract removeProductsFromCart(productSku: string): Array<string>;
    abstract getProductsCartList(): Array<string>;
}
export {};
